@@ -96,13 +96,13 @@ ObjectClass = Literal[
     "motion",
 ]
 CameraRoles = Literal["high-resolution", "mid-resolution", "low-resolution", "snapshot"]
-DecoderFormat = Literal["yuv", "rgb"]
-ImageInputFormat = Literal["yuv", "rgb", "rgba", "gray"]
+DecoderFormat = Literal["yuv420p", "rgb24", "nv12"]
+ImageInputFormat = Literal["yuv420p", "nv12", "rgb", "rgba", "gray"]
 ImageOutputFormat = Literal["rgb", "rgba", "gray"]
 CameraExtension = Literal[
     "cameraController", "hub", "motionDetection", "objectDetection", "audioDetection", "ptz"
 ]
-CameraFrameWorkerDecoder = Literal["pillow", "wasm", "rust"]
+CameraFrameWorkerDecoder = Literal["pillow", "wasm", "rust", "gpu"]
 CameraFrameWorkerResolution = Literal[
     "640x480",
     "640x360",
@@ -539,6 +539,8 @@ class VideoFrame(Protocol):
     @property
     def timestamp(self) -> int: ...
     @property
+    def motion(self) -> Optional[MotionSetEvent]: ...
+    @property
     def input_width(self) -> int: ...
     @property
     def input_height(self) -> int: ...
@@ -550,11 +552,6 @@ class VideoFrame(Protocol):
     async def save(self, path: str, options: Optional[ImageOptions] = None) -> None: ...
 
 
-class MotionFrame(VideoFrame, Protocol):
-    @property
-    def motion(self) -> Optional[MotionSetEvent]: ...
-
-
 class CameraInputSettings(TypedDict):
     _id: str
     name: str
@@ -875,7 +872,7 @@ class CameraDevice(Protocol):
     @overload
     def get_frames(
         self, frame_type: Literal["motion"], options: Optional[ImageOptions] = None
-    ) -> AsyncGenerator[MotionFrame, None]: ...
+    ) -> AsyncGenerator[VideoFrame, None]: ...
 
     @overload
     async def update_state(
